<?php
session_start();
include 'config.php';
include 'header.php';
include 'sidebar.php';

if (!isset($_SESSION['id'])) {
    header("Location: login.php");
    exit();
}

$user_id = $_SESSION['id'];
$type_utilisateur = $_SESSION['type'];

// 🔍 Filtres (facultatifs)
$filtre_nom = $_GET['filtre_nom'] ?? '';
$filtre_date = $_GET['filtre_date'] ?? '';

// ⚙️ Requête SQL optimisée
$sql = "
    SELECT 
        r.id AS reservation_id,
        s.nom_service,
        u.nom AS interlocuteur,
        u.photo,
        MAX(m.date_envoi) AS dernier_message,
        SUBSTRING_INDEX(MAX(CONCAT(m.date_envoi, '|', m.message)), '|', -1) AS snippet,
        SUM(CASE WHEN m.destinataire_id = ? AND m.lu = 0 THEN 1 ELSE 0 END) AS non_lus
    FROM reservations r
    JOIN services s ON r.service_id = s.id
    JOIN utilisateurs u 
        ON (r.client_id = ? AND u.id = s.prestataire_id)
        OR (s.prestataire_id = ? AND u.id = r.client_id)
    LEFT JOIN messages m ON r.id = m.reservation_id
    WHERE (r.client_id = ? OR s.prestataire_id = ?)
";

// Ajout des filtres
if (!empty($filtre_nom)) {
    $sql .= " AND u.nom LIKE ?";
}
if (!empty($filtre_date)) {
    $sql .= " AND DATE(m.date_envoi) = ?";
}

$sql .= " GROUP BY r.id, s.nom_service, u.nom, u.photo ORDER BY dernier_message DESC";

$stmt = $conn->prepare($sql);

// 📌 Bind dynamique selon filtres
if (!empty($filtre_nom) && !empty($filtre_date)) {
    $like_nom = "%" . $filtre_nom . "%";
    $stmt->bind_param("iiiiis", $user_id, $user_id, $user_id, $user_id, $user_id, $like_nom, $filtre_date);
} elseif (!empty($filtre_nom)) {
    $like_nom = "%" . $filtre_nom . "%";
    $stmt->bind_param("iiiii", $user_id, $user_id, $user_id, $user_id, $user_id, $like_nom);
} elseif (!empty($filtre_date)) {
    $stmt->bind_param("iiiii", $user_id, $user_id, $user_id, $user_id, $user_id, $filtre_date);
} else {
    $stmt->bind_param("iiiii", $user_id, $user_id, $user_id, $user_id, $user_id);
}

$stmt->execute();
$result = $stmt->get_result();
?>

<!DOCTYPE html>
<html lang="fr">
<head>
    <meta charset="UTF-8">
    <title>📨 Messagerie | ProBooker</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <style>
        .chat-photo {
            width: 50px;
            height: 50px;
            object-fit: cover;
            border-radius: 50%;
        }
        .chat-card {
            transition: 0.3s;
            border-left: 4px solid transparent;
        }
        .chat-card:hover {
            background-color: #f8f9fa;
        }
        .chat-card.unread {
            border-left-color: #764ba2;
            background: #fff8f8;
        }
        .badge-nl {
            background-color: red;
            color: white;
            font-size: 0.75rem;
        }
    </style>
    <script>
        setInterval(() => {
            fetch(window.location.href)
                .then(response => response.text())
                .then(html => {
                    const parser = new DOMParser();
                    const doc = parser.parseFromString(html, 'text/html');
                    const updatedList = doc.querySelector("#chat-container");
                    if (updatedList) {
                        document.querySelector("#chat-container").innerHTML = updatedList.innerHTML;
                    }
                });
        }, 15000); // Rafraîchissement toutes les 15s
    </script>
</head>
<body>
<div class="container mt-4">
    <h3 class="mb-4">📨 Messagerie</h3>

    <!-- 🔍 Filtres -->
    <form method="get" class="row g-2 mb-4">
        <div class="col-md-4">
            <input type="text" name="filtre_nom" value="<?= htmlspecialchars($filtre_nom) ?>" class="form-control" placeholder="🔎 Rechercher par nom">
        </div>
        <div class="col-md-3">
            <input type="date" name="filtre_date" value="<?= htmlspecialchars($filtre_date) ?>" class="form-control">
        </div>
        <div class="col-md-2">
            <button type="submit" class="btn btn-primary w-100">Filtrer</button>
        </div>
        <div class="col-md-2">
            <a href="messagerie.php" class="btn btn-outline-secondary w-100">Réinitialiser</a>
        </div>
    </form>

    <!-- 📨 Liste des conversations -->
    <div class="list-group" id="chat-container">
        <?php if ($result->num_rows === 0): ?>
            <div class="alert alert-info">Aucune conversation trouvée.</div>
        <?php else: ?>
            <?php while ($row = $result->fetch_assoc()): ?>
                <a href="discussion.php?reservation_id=<?= $row['reservation_id'] ?>" 
                   class="list-group-item list-group-item-action d-flex justify-content-between align-items-center chat-card <?= $row['non_lus'] > 0 ? 'unread' : '' ?>">
                    <div class="d-flex align-items-center gap-3">
                        <img src="<?= !empty($row['photo']) ? $row['photo'] : 'uploads/default.jpg' ?>" class="chat-photo">
                        <div>
                            <div><strong><?= htmlspecialchars($row['interlocuteur']) ?></strong> <small class="text-muted">#<?= $row['reservation_id'] ?></small></div>
                            <small class="text-muted"><?= htmlspecialchars($row['nom_service']) ?></small><br>
                            <small><?= $row['dernier_message'] ? date("d/m H:i", strtotime($row['dernier_message'])) : '' ?> - 
                                <?= htmlspecialchars(mb_strimwidth($row['snippet'], 0, 40, "...")) ?>
                            </small>
                        </div>
                    </div>
                    <?php if ($row['non_lus'] > 0): ?>
                        <span class="badge rounded-pill badge-nl"><?= $row['non_lus'] ?></span>
                    <?php endif; ?>
                </a>
            <?php endwhile; ?>
        <?php endif; ?>
    </div>
</div>
</body>
</html>
